"""An inbound email handler for Django."""

__title__ = 'django-inbound-email'
__version__ = '0.3.1'
__author__ = 'YunoJuno Ltd'
__license__ = 'MIT'
__copyright__ = 'Copyright 2014 YunoJuno'
__description__ = (
    "A Django app to make it easy to receive inbound emails from "
    "a hosted transactional email service (e.g. SendGrid, Postmark, "
    "Mandrill, etc.)."
)



# Signals definitions for django-inbound-email
from django.dispatch import Signal

# this is fired when a new email has been successfully parsed
# from the inbound view function.
email_received = Signal(providing_args=['email', 'request'])
